@@ -21,7 +21,13 @@ ALLOWED_HOSTS = env("ALLOWED_HOSTS")
 # Application definition
 
 INSTALLED_APPS = [
+    "birder.theme",
     "daphne",
+    "unfold",  # before django.contrib.admin
+    "unfold.contrib.filters",  # optional, if special filters are needed
+    "unfold.contrib.forms",  # optional, if special form elements are needed
+    "unfold.contrib.inlines",  # optional, if special inlines are needed
+    "unfold.contrib.simple_history",  # optional, if dja
     "django.contrib.admin",
     "django.contrib.auth",
     "django.contrib.contenttypes",
@@ -34,11 +40,11 @@ INSTALLED_APPS = [
     "dramatiq_crontab",
     "adminfilters",
     "constance",
+    "recurrence",
     "flags",
     "social_django",
     "tailwind",
     "birder",
-    "birder.theme",
     "birder.ws",
     *env("EXTRA_APPS"),
 ]
@@ -182,6 +188,7 @@ LOGGING = {
 }
 CSRF_TRUSTED_ORIGINS = env("CSRF_TRUSTED_ORIGINS")
 SECURE_PROXY_SSL_HEADER = ("HTTP_X_FORWARDED_PROTO", "https")
+SECURE_HSTS_SECONDS = env("SECURE_HSTS_SECONDS")
 
 from .fragments.app import *  # noqa
 from .fragments.constance import *  # noqa
@@ -190,3 +197,4 @@ from .fragments.crypt import *  # noqa
 from .fragments.dramatiq import *  # noqa
 from .fragments.social_auth import *  # noqa
 from .fragments.tailwind import *  # noqa
+from .fragments.unfold import *  # noqa
