@@ -1,10 +1,12 @@
 from collections.abc import Iterable
-from datetime import datetime
+from datetime import date, datetime
 from enum import StrEnum
 from functools import cached_property
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
+import recurrence.fields
 from constance import config
+from dateutil.relativedelta import relativedelta
 from django.conf import settings
 from django.contrib.auth.models import AbstractUser, Group
 from django.core.cache import cache
@@ -14,6 +16,7 @@ from django.db import models
 from django.db.models.base import ModelBase
 from django.db.models.functions.text import Lower
 from django.templatetags.static import static
+from django.urls import reverse
 from django.utils import timezone
 from django.utils.translation import gettext as _
 from django_stubs_ext.db.models import TypedModelMeta
@@ -41,6 +44,9 @@ KEY_PROGRAM_CHECKS = "{0}:program:{1.pk}:checks"
 
 valkey = Valkey.from_url(settings.DRAMATIQ_VALKEY_URL)
 
+if TYPE_CHECKING:
+    from django.db.models.manager import _T
+
 
 def get_cache_key(pattern: str, *args: Any) -> str:
     return pattern.format(config.CACHE_PREFIX, *args)
@@ -57,7 +63,7 @@ class Project(models.Model):
     bitcaster_url = models.URLField(blank=True, help_text="The URL to the Bitcaster notification endpoint.")
     environments = models.ManyToManyField("Environment", related_name="projects", blank=False)
     icon = models.CharField(blank=True, default="", max_length=255)
-    default_environment = models.ForeignKey("Environment", null=True, on_delete=models.PROTECT)
+    default_environment = models.ForeignKey("Environment", null=True, on_delete=models.PROTECT)  # type: ignore[misc]
 
     class Meta:
         ordering = ["name"]
@@ -80,9 +86,17 @@ class Project(models.Model):
             self.default_environment = self.environments.first()
         super().save(force_insert=force_insert, force_update=force_update, using=using, update_fields=update_fields)
 
+    def get_absolute_url(self) -> str:
+        env = self.default_environment if self.default_environment else self.environments.first()
+        return reverse("project-env", kwargs={"project_id": self.pk, "env": env.name})
+
     def clean(self) -> None:
-        if self.default_environment and not self.environments.filter(pk=self.default_environment.pk).exists():
-            raise ValidationError(_("Default environment mus be one of selected environment"))
+        if (
+            self.pk
+            and self.default_environment
+            and not self.environments.filter(pk=self.default_environment.pk).exists()
+        ):
+            raise ValidationError(_("Default environment must be one of selected environment"))
         super().clean()
 
     @cached_property
@@ -136,6 +150,17 @@ class UserRole(models.Model):
         return self.user.username
 
 
+class MonitorQuerySet(models.query.QuerySet):
+    pass
+
+
+class MonitorManager(models.Manager):
+    queryset_class = MonitorQuerySet
+
+    def get_queryset(self) -> "models.QuerySet[_T]":
+        return super().get_queryset().select_related("environment", "project")
+
+
 class Monitor(models.Model):
     class Status(StrEnum):
         SUCCESS = "ok"
@@ -145,17 +170,15 @@ class Monitor(models.Model):
 
     strategy: "BaseCheck"
     project = models.ForeignKey(Project, on_delete=models.CASCADE)
-    environment = models.ForeignKey(Environment, on_delete=models.SET_NULL, null=True, blank=False)
+    environment = models.ForeignKey(Environment, on_delete=models.SET_NULL, null=True, blank=False)  # type: ignore[misc]
     name = models.CharField(max_length=255, unique=True)
     position = models.PositiveIntegerField(default=0)
     description = models.TextField(blank=True, help_text="short description  to display in the monitor detail page")
     notes = models.TextField(blank=True, help_text="Notes about the monitor. Only visible to Staff")
     custom_icon = models.CharField(blank=True, default="", max_length=255)
-
     strategy = StrategyField(registry=registry)
     configuration = EncryptedJSONField(default=dict, help_text="Checker configuration")
-
-    data = models.BinaryField(blank=True, null=True, default=None)
+    data = models.BinaryField(blank=True, null=True, default=None)  # type: ignore[misc]
     data_file = models.FileField(blank=True, null=True, default=None)
 
     token = models.CharField(
@@ -180,14 +203,24 @@ class Monitor(models.Model):
         "(or missing notifications in case or remote invocation) produce an error",
     )
 
+    objects = MonitorManager()
+
     class Meta(TypedModelMeta):
-        ordering = ("name",)
+        ordering = (
+            "project__name",
+            "name",
+        )
         constraints = [
             models.UniqueConstraint("project", Lower("name"), name="unique_project_monitor_name"),
         ]
 
     def __str__(self) -> str:
-        return self.name
+        return f"{self.project.name}/{self.name} ({self.environment.name})"
+
+    def get_absolute_url(self) -> str:
+        return reverse(
+            "monitor-detail", kwargs={"project_id": self.project.pk, "env": self.environment.name, "pk": self.pk}
+        )
 
     @cached_property
     def icon(self) -> str:
@@ -233,6 +266,7 @@ class Monitor(models.Model):
 
             if result:
                 self.reset_current_errors()
+                self.store_last_timestamp_success()
                 st = Monitor.Status.SUCCESS
             else:
                 self.store_error(timestamp)
@@ -332,7 +366,7 @@ class Monitor(models.Model):
 class DataHistory(models.Model):
     monitor = models.ForeignKey(Monitor, on_delete=models.CASCADE, related_name="datalog")
     date = models.DateField(auto_now_add=False)
-    data = models.BinaryField(default=None, null=True)
+    data = models.BinaryField(default=None, null=True)  # type: ignore[misc]
 
     class Meta:
         ordering = ["-date"]
@@ -355,3 +389,34 @@ class LogCheck(models.Model):
 
     def __str__(self) -> str:
         return self.monitor.name
+
+
+class Deadline(models.Model):
+    monitor = models.ForeignKey(Monitor, on_delete=models.CASCADE, related_name="deadlines")
+    title = models.CharField(max_length=100)
+    description = models.TextField(blank=True)
+    start = models.DateField(default=timezone.now)
+    end = models.DateField(blank=True, null=True)  # type: ignore[misc]
+    recurrences = recurrence.fields.RecurrenceField()
+    warn_threshold = models.IntegerField(default=7, help_text="How many days before the deadline should warn monitor")
+    alarm_threshold = models.IntegerField(default=1, help_text="How many days before the deadline should alarm monitor")
+
+    class Meta:
+        ordering = ["-start"]
+
+    def __str__(self) -> str:
+        return self.title
+
+    @cached_property
+    def next(self) -> date:
+        return self.recurrences.after(datetime.today(), inc=True).date()
+
+    @property
+    def is_warn(self) -> bool:
+        warn_offset = (datetime.today() - relativedelta(days=self.warn_threshold)).date()
+        return self.next > warn_offset
+
+    @property
+    def is_expiring(self) -> bool:
+        alarm_offset = (datetime.today() - relativedelta(days=self.warn_threshold)).date()
+        return self.next > alarm_offset
